@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2004, Industrial Light & Magic, a division of Lucas
+// Copyright (c) 2004-2012, Industrial Light & Magic, a division of Lucas
 // Digital Ltd. LLC
 // 
 // All rights reserved.
@@ -33,8 +33,6 @@
 ///////////////////////////////////////////////////////////////////////////
 
 
-#include <tmpDir.h>
-
 #include <ImfTiledOutputFile.h>
 #include <ImfTiledInputFile.h>
 #include <ImfInputFile.h>
@@ -52,15 +50,14 @@
 #include <math.h>
 #include <ImfTileDescriptionAttribute.h>
 
-using namespace Imf;
-using namespace Imath;
+
+namespace IMF = OPENEXR_IMF_NAMESPACE;
+using namespace IMF;
 using namespace std;
+using namespace IMATH_NAMESPACE;
 
 namespace {
 
-using Imf::UINT;
-using Imf::HALF;
-using Imf::FLOAT;
 
 void
 fillPixels (Array2D<unsigned int> &pi,
@@ -120,30 +117,30 @@ writeRead (const Array2D<unsigned int> &pi1,
     hdr.lineOrder() = lorder;
     hdr.compression() = comp;
 
-    hdr.channels().insert ("I", Channel (UINT));
-    hdr.channels().insert ("H", Channel (HALF));
-    hdr.channels().insert ("F", Channel (FLOAT));
+    hdr.channels().insert ("I", Channel (IMF::UINT));
+    hdr.channels().insert ("H", Channel (IMF::HALF));
+    hdr.channels().insert ("F", Channel (IMF::FLOAT));
     
     hdr.setTileDescription(TileDescription(xSize, ySize, mode, rmode));
     {
         FrameBuffer fb; 
 
         fb.insert ("I",                                       // name
-                   Slice (UINT,                               // type
+                   Slice (IMF::UINT,                          // type
                           (char *) &pi1[-yOffset][-xOffset],  // base
                           sizeof (pi1[0][0]),                 // xStride
                           sizeof (pi1[0][0]) * width)         // yStride
                   );
                   
         fb.insert ("H",                                       // name
-                   Slice (HALF,                               // type
+                   Slice (IMF::HALF,                          // type
                           (char *) &ph1[-yOffset][-xOffset],  // base
                           sizeof (ph1[0][0]),                 // xStride
                           sizeof (ph1[0][0]) * width)         // yStride
                   );
                   
         fb.insert ("F",                                       // name
-                   Slice (FLOAT,                              // type
+                   Slice (IMF::FLOAT,                              // type
                           (char *) &pf1[-yOffset][-xOffset],  // base
                           sizeof (pf1[0][0]),                 // xStride
                           sizeof (pf1[0][0]) * width)         // yStride
@@ -262,21 +259,21 @@ writeRead (const Array2D<unsigned int> &pi1,
         FrameBuffer fb;
 
         fb.insert ("I",                             // name
-                   Slice (UINT,                     // type
+                   Slice (IMF::UINT,                // type
                           (char *) &pi2[-dwy][-dwx],// base
                           sizeof (pi2[0][0]),       // xStride
                           sizeof (pi2[0][0]) * w)   // yStride
                   );
 
         fb.insert ("H",                             // name
-                   Slice (HALF,                     // type
+                   Slice (IMF::HALF,                // type
                           (char *) &ph2[-dwy][-dwx],// base
                           sizeof (ph2[0][0]),       // xStride
                           sizeof (ph2[0][0]) * w)   // yStride
                   );
 
         fb.insert ("F",                             // name
-                   Slice (FLOAT,                    // type
+                   Slice (IMF::FLOAT,               // type
                           (char *) &pf2[-dwy][-dwx],// base
                           sizeof (pf2[0][0]),       // xStride
                           sizeof (pf2[0][0]) * w)   // yStride
@@ -341,21 +338,21 @@ writeRead (const Array2D<unsigned int> &pi1,
         FrameBuffer fb;
 
         fb.insert ("I",                             // name
-                   Slice (UINT,                     // type
+                   Slice (IMF::UINT,                // type
                           (char *) &pi2[-dwy][-dwx],// base
                           sizeof (pi2[0][0]),       // xStride
                           sizeof (pi2[0][0]) * w)   // yStride
                   );
 
         fb.insert ("H",                             // name
-                   Slice (HALF,                     // type
+                   Slice (IMF::HALF,                // type
                           (char *) &ph2[-dwy][-dwx],// base
                           sizeof (ph2[0][0]),       // xStride
                           sizeof (ph2[0][0]) * w)   // yStride
                   );
 
         fb.insert ("F",                             // name
-                   Slice (FLOAT,                    // type
+                   Slice (IMF::FLOAT,               // type
                           (char *) &pf2[-dwy][-dwx],// base
                           sizeof (pf2[0][0]),       // xStride
                           sizeof (pf2[0][0]) * w)   // yStride
@@ -423,21 +420,21 @@ writeRead (const Array2D<unsigned int> &pi1,
 	    FrameBuffer fb;
 
 	    fb.insert ("I",					// name
-		       Slice (UINT,				// type
+		       Slice (IMF::UINT,			// type
 			      (char *) &pi2[y - dwy][-dwx],	// base
 			      sizeof (pi2[0][0]),		// xStride
 			      0)				// yStride
 		      );
 
 	    fb.insert ("H",					// name
-		       Slice (HALF,				// type
+		       Slice (IMF::HALF,			// type
 			      (char *) &ph2[y - dwy][-dwx],	// base
 			      sizeof (ph2[0][0]),		// xStride
 			      0)				// yStride
 		      );
 
 	    fb.insert ("F",                     	        // name
-		       Slice (FLOAT,				// type
+		       Slice (IMF::FLOAT,			// type
 			      (char *) &pf2[y - dwy][-dwx],	// base
 			      sizeof (pf2[0][0]),		// xStride
 			      0)				// yStride
@@ -490,7 +487,8 @@ writeRead (const Array2D<unsigned int> &pi1,
 
 
 void
-writeRead (const Array2D<unsigned int> &pi,
+writeRead (const std::string &tempDir,
+           const Array2D<unsigned int> &pi,
            const Array2D<half> &ph,
            const Array2D<float> &pf,
            int W,
@@ -501,13 +499,13 @@ writeRead (const Array2D<unsigned int> &pi,
            int dx, int dy,
            int xSize, int ySize)
 {
-    const char *filename = IMF_TMP_DIR "imf_test_scanline_api.exr";
+    std::string filename = tempDir + "imf_test_scanline_api.exr";
 
-    writeRead (pi, ph, pf, filename, lorder, W, H,
+    writeRead (pi, ph, pf, filename.c_str(), lorder, W, H,
                xSize, ySize, dx, dy, comp, ONE_LEVEL, rmode);
-    writeRead (pi, ph, pf, filename, lorder, W, H,
+    writeRead (pi, ph, pf, filename.c_str(), lorder, W, H,
                xSize, ySize, dx, dy, comp, MIPMAP_LEVELS, rmode);
-    writeRead (pi, ph, pf, filename, lorder, W, H,
+    writeRead (pi, ph, pf, filename.c_str(), lorder, W, H,
                xSize, ySize, dx, dy, comp, RIPMAP_LEVELS, rmode);
 }
 
@@ -515,7 +513,7 @@ writeRead (const Array2D<unsigned int> &pi,
 
 
 void
-testScanLineApi ()
+testScanLineApi (const std::string &tempDir)
 {
     try
     {
@@ -531,11 +529,11 @@ testScanLineApi ()
         Array2D<float> pf (H, W);
         fillPixels (pi, ph, pf, W, H);
 
-	int maxThreads = IlmThread::supportsThreads()? 3: 0;
+	int maxThreads = ILMTHREAD_NAMESPACE::supportsThreads()? 3: 0;
 
 	for (int n = 0; n <= maxThreads; ++n)
 	{
-	    if (IlmThread::supportsThreads())
+	    if (ILMTHREAD_NAMESPACE::supportsThreads())
 	    {
 		setGlobalThreadCount (n);
 		cout << "\nnumber of threads: " << globalThreadCount() << endl;
@@ -545,49 +543,49 @@ testScanLineApi ()
 	    {
 		for (int rmode = 0; rmode < NUM_ROUNDINGMODES; ++rmode)
 		{
-		    writeRead (pi, ph, pf,  W, H, 
+		    writeRead (tempDir, pi, ph, pf,  W, H, 
 			       LineOrder (lorder),
 			       ZIP_COMPRESSION,
 			       LevelRoundingMode (rmode),
 			       0, 0, 1, 1);
 
-		    writeRead (pi, ph, pf, W, H, 
+		    writeRead (tempDir, pi, ph, pf, W, H, 
 			       LineOrder (lorder),
 			       ZIP_COMPRESSION,
 			       LevelRoundingMode (rmode),
 			       DX, DY, 1, 1);
 		    
-		    writeRead (pi, ph, pf, W, H,
+		    writeRead (tempDir, pi, ph, pf, W, H,
 			       LineOrder (lorder),
 			       ZIP_COMPRESSION,
 			       LevelRoundingMode (rmode),
 			       0, 0, 24, 26);
 
-		    writeRead (pi, ph, pf, W, H,
+		    writeRead (tempDir, pi, ph, pf, W, H,
 			       LineOrder (lorder),
 			       ZIP_COMPRESSION,
 			       LevelRoundingMode (rmode),
 			       DX, DY, 24, 26);
 		    
-		    writeRead (pi, ph, pf, W, H,
+		    writeRead (tempDir, pi, ph, pf, W, H,
 			       LineOrder (lorder),
 			       ZIP_COMPRESSION,
 			       LevelRoundingMode (rmode),
 			       0, 0, 48, 81);
 
-		    writeRead (pi, ph, pf, W, H,
+		    writeRead (tempDir, pi, ph, pf, W, H,
 			       LineOrder (lorder),
 			       ZIP_COMPRESSION,
 			       LevelRoundingMode (rmode),
 			       DX, DY, 48, 81);
 			       
-		    writeRead (pi, ph, pf, W, H,
+		    writeRead (tempDir, pi, ph, pf, W, H,
 			       LineOrder (lorder),
 			       ZIP_COMPRESSION,
 			       LevelRoundingMode (rmode),
 			       0, 0, 128, 96);
 
-		    writeRead (pi, ph, pf, W, H,
+		    writeRead (tempDir, pi, ph, pf, W, H,
 			       LineOrder (lorder),
 			       ZIP_COMPRESSION,
 			       LevelRoundingMode (rmode),
