@@ -34,6 +34,7 @@
 
 
 #include "compareB44.h"
+#include "compareDwa.h"
 
 #include <ImfRgbaFile.h>
 #include <ImfArray.h>
@@ -248,6 +249,11 @@ writeReadRGBA (const char fileName[],
 	{
 	    compareB44 (width, height, p1, p2, channels);
 	}
+	else if (in.compression() == DWAA_COMPRESSION ||
+	         in.compression() == DWAB_COMPRESSION)
+	{
+	    compareDwa (width, height, p1, p2, channels);
+	}
 	else
 	{
 	    for (int y = 0; y < h; ++y)
